# File generated from our OpenAPI spec by Stainless.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["TextBlockParam"]


class TextBlockParam(TypedDict, total=False):
    text: Required[str]

    type: Literal["text"]



# File generated from our OpenAPI spec by Stainless.

from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["MessageStopEvent"]


class MessageStopEvent(BaseModel):
    type: Literal["message_stop"]



# File generated from our OpenAPI spec by Stainless.

from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["ContentBlockStopEvent"]


class ContentBlockStopEvent(BaseModel):
    index: int

    type: Literal["content_block_stop"]



# File generated from our OpenAPI spec by Stainless.

from typing import Union

from .message_stop_event import MessageStopEvent
from .message_delta_event import MessageDeltaEvent
from .message_start_event import MessageStartEvent
from .content_block_stop_event import ContentBlockStopEvent
from .content_block_delta_event import ContentBlockDeltaEvent
from .content_block_start_event import ContentBlockStartEvent

__all__ = ["MessageStreamEvent"]

MessageStreamEvent = Union[
    MessageStartEvent,
    MessageDeltaEvent,
    MessageStopEvent,
    ContentBlockStartEvent,
    ContentBlockDeltaEvent,
    ContentBlockStopEvent,
]
